link_machine

Function link_machine 

pub fn link_machine(target: TargetTuple) -> Option<&'static str>
Which machine lld-link is to write for, in the name -machine: knows it by.

Microsoft’s names, which are neither the architecture’s nor GNU ld’s. None for a target that is not in Microsoft’s environment, whose linker reads pe_machine instead.