pub struct Wanted {
pub package: String,
pub version: String,
pub payload: Payload,
}Expand description
One file to download, and which package of Microsoft’s it came out of.
Fields
package: StringThe package id, which is what a provenance record names as the source.
version: StringThe package version, which is the version of that source.
payload: PayloadThe file itself.